****************************************************************************************************
* RDC32 v71NA - PERE SERRAT / SIMON JONASSEN - 2016-12-17
****************************************************************************************************
* This is based on ChewBaccA ROTOZOOM ported to Dragon64/CoCo2 to rotate a PM3 image without zoom
* To keep compatibility with CoCo, the image will begin at $e00
* The source image in PMODE3 is 128 pixels wide x 128 pixels high
* We have 32 bytes per scanline, so each byte has info about FOUR pixels
* The texture is preprocessed and converted to 256 bytes per row, each byte containing info of a pixel
* and the last 128 bytes are filled with zeroes. Will be located from $8000 to $FDFF in MAP1
* Each screen byte will be processed as is: four pixels (2 bits each)
* We are going to use a reduced viewport to avoid "looking" outside the texture / screen
* it will be just 80 x 80 pixels, so 20 bytes wide (centered on screen)
* The X coordinate will be processed from 0 to 79 - The Y from 0 to 79 (so, rotating a square)
****************************************************************************************************
			opt	6809							; force code for MC6809
			opt 	cd								; set cycle counting
			opt	ct								; set totals on
			org	$2d00
* --------------------------------------------------------------------------------------------------
* SYSTEM CONFIGURATION
* --------------------------------------------------------------------------------------------------
start		pshs	cc,dp							; save DP and flags
			orcc	#$50							; disable interrupts
			lda	#$c0							; value for PMode1, SCREEN1,0
			sta	$ffd7							; ROM at double spped
			sta	$ffc7							; offset b1=1
			sta	$ffc8							; offset b2=0
			sta	$ffcb							; offset b3=1
			sta	$ffcd							; offset b4=1
			sta	$ffce							; offset b5=0
			sta	$ffd0							; offset b6=0
			sta	$ffd2							; offset b7=0  -- 0001101 = 13 (13 * $200 = $1a00)  
			sta	$ffc0							; SAM V0=0
			sta	$ffc2							; SAM V1=0
			sta	$ffc5							; SAM V2=1  -- PMODE1
			sta	$ff22							; PIA=$c0   -- 3072 bytes, palette 0
			lda	#$05							; set bits 0 and 2
			sta	$ff03							; to detect FS at end of screen
			sta	$ffdf							; switch to MAP1
			lda	#linCnt/256					; get beginning of process for Words
			tfr	a,dp							; set as DP
			clr	<angStep						; set to 0 - will range 0-254 step 2
****************************************************************************************************
* FRAME BEGIN CODE
****************************************************************************************************
			opt 	cc
nxtFrame	ldy	#$1b06						; set begining of buffer area (Page 3, 9th line, 7th byte!)
			ldx	#posIX						; point to posIX table
			ldx	b,x							; retrieve X value
			stx	<initIX+1					; store in X initial value
			stx	<workIX1+1					; store in X working value
			ldx	#posIY						; point to posIY table
			ldx	b,x							; retrieve Y value
			stx	<initIY+1					; store in Y initial value
			stx	<workIY1+1					; store in Y working value
			ldx	#costab						; point to cosine table
			ldx	b,x							; get cosine value for angle
			stx	<cosine+1					; save cosine value
			stx	<cos1+1						; save to working value for pixel 1
			stx	<cos2+1						; save to working value for pixel 2
			stx	<cos3+1						; save to working value for pixel 3				
			stx	<cos4+1						; save to working value for pixel 4
			stx	<cos5+1						; save to working value for pixel 5
			stx	<cos6+1						; save to working value for pixel 6
			stx	<cos7+1						; save to working value for pixel 7				
			stx	<cos8+1						; save to working value for pixel 8
			ldx	#sintab						; point to sine table
			ldx	b,x							; get sine values for angle
			stx	<sine+1						; save sine value	
			stx	<sin1+1						; save to working value for pixel 1
			stx	<sin2+1						; save to working value for pixel 2
			stx	<sin3+1						; save to working value for pixel 3
			stx	<sin4+1						; save to working value for pixel 4
			stx	<sin5+1						; save to working value for pixel 5
			stx	<sin6+1						; save to working value for pixel 6
			stx	<sin7+1						; save to working value for pixel 7
			stx	<sin8+1						; save to working value for pixel 8
			lda	#80							; put number of vertical pixels to process
			sta	<linCnt						; into line counter
			ldx	#$8000						; point to texture beginning
			jmp	<nxtLin						; skip alignement filler
****************************************************************************************************
* PROGRAM LOCAL VARIABLES
****************************************************************************************************
			align	$100							; to allow for more direct addressing operations
linCnt	fcb	$00							; line counter
angStep	fcb	$00							; step of angle rotation
wordCnt	fcb	$00							; counter for words in a line
****************************************************************************************************
* LINE BEGINNING CODE
****************************************************************************************************
			opt 	cc
nxtLin	ldb	#10							; put number of words x line
			stb	<wordCnt						; into byte counter
****************************************************************************************************
* WORD BEGINNING CODE
****************************************************************************************************
nxtWord	opt 	cc
workIX1	ldd	#$0000						; get X coordinate
			sta	<dd1+3						; use high byte as offset to get the pixel 1 from texture
cos1		addd	#$0000						; add cosine of rotation angle
			sta	<dd2+3						; use high byte as offset to get the pixel 2 from texture
cos2		addd	#$0000						; add cosine of rotation angle
			sta	<dd3+3						; use high byte as offset to get the pixel 3 from texture
cos3		addd	#$0000						; add cosine of rotation angle
			sta	<dd4+3						; use high byte as offset to get the pixel 4 from texture
cos4		addd	#$0000						; add cosine of rotation angle
			sta	<dd5+3						; use high byte as offset to get the pixel 5 from texture
cos5		addd	#$0000						; add cosine of rotation angle
			sta	<dd6+3						; use high byte as offset to get the pixel 6 from texture
cos6		addd	#$0000						; add cosine of rotation angle
			sta	<dd7+3						; use high byte as offset to get the pixel 7 from texture
cos7		addd	#$0000						; add cosine of rotation angle
			sta	<dd8+3						; use high byte as offset to get the pixel 8 from texture
cos8		addd	#$0000						; add cosine of rotation angle
			std	<workIX1+1					; save for next word process
workIY1	ldd	#$0000						; get Y coordinate			
			sta	<dd1+2						; put high byte as pointer low byte
sin1		subd	#$0000						; subtract sine of rotation angle
			sta	<dd2+2						; put high byte as pointer low byte
sin2		subd	#$0000						; subtract sine of rotation angle
			sta	<dd3+2						; put high byte as pointer low byte
sin3		subd	#$0000						; subtract sine of rotation angle
			sta	<dd4+2						; put high byte as pointer low byte
sin4		subd	#$0000						; subtract sine of rotation angle
			sta	<dd5+2						; put high byte as pointer low byte
sin5		subd	#$0000						; subtract sine of rotation angle
			sta	<dd6+2						; put high byte as pointer low byte
sin6		subd	#$0000						; subtract sine of rotation angle
			sta	<dd7+2						; put high byte as pointer low byte
sin7		subd	#$0000						; subtract sine of rotation angle
			sta	<dd8+2						; put high byte as pointer low byte
sin8		subd	#$0000						; subtract sine of rotation angle
			std	<workIY1+1					; save for next word process
****************************************************************************************************
* Pixel ONE CODE
****************************************************************************************************
dd1		ldb	1234,x
			ldu	#pixShft1					; point to color table for Pixel 1
			lda	b,u							; get color value to use
****************************************************************************************************
* PIxel TWO CODE
****************************************************************************************************
dd2		ldb	1234,x
			ldu	#pixShft2					; point to color table for Pixel 2
			ora	b,u							; add pixel to previous accumulated data
****************************************************************************************************
* PIxel THREE CODE
****************************************************************************************************
dd3		ldb	1234,x
			ldu	#pixShft3					; point to color table for Pixel 2
			ora	b,u							; add pixel to previous accumulated data
****************************************************************************************************
* PIxel FOUR CODE
****************************************************************************************************
dd4		ldb	1234,x
			ldu	#pixShft4					; point to color table for Pixel 2
			ora	b,u							; add pixel to previous accumulated data
			sta	,y+							; update 1st byte on screen
****************************************************************************************************
* PIxel FIVE CODE
****************************************************************************************************
dd5		ldb	1234,x
			ldu	#pixShft1					; point to color table for Pixel 2
			lda	b,u							; add pixel to previous accumulated data
****************************************************************************************************
* PIxel SIX CODE
****************************************************************************************************
dd6		ldb	1234,x
			ldu	#pixShft2					; point to color table for Pixel 2
			ora	b,u							; add pixel to previous accumulated data
****************************************************************************************************
* PIxel SEVEN CODE
****************************************************************************************************
dd7		ldb	1234,x
			ldu	#pixShft3					; point to color table for Pixel 2
			ora	b,u							; add pixel to previous accumulated data
****************************************************************************************************
* PIxel EIGHT CODE
****************************************************************************************************
dd8		ldb	1234,x
			ldu	#pixShft4					; point to color table for Pixel 2
			ora	b,u							; add pixel to previous accumulated data
			sta	,y+							; update 2nd byte on screen
****************************************************************************************************
* WORD END CODE
****************************************************************************************************
			dec	<wordCnt						; decrement word counter
			lbne	nxtWord						; not done, loopback
****************************************************************************************************
* LINE END CODE
****************************************************************************************************
			opt 	cc								; Calculate beginning coordinates for next Line
initIX	ldd	#$0000						; get saved value for X coordinate of previous line beginning 
sine		addd	#$0000						; acumulate sine (must add if positive)
			std	<initIX+1					; update initial value for IX
			std	<workIX1+1					; same with working value for pixel 1
initIY	ldd	#$0000						; get saved value for Y coordinate of previous line beginning
cosine	addd	#$0000						; acumulate cosine (must add if positive)
			std	<initIY+1					; update initial value for IY
			std	<workIY1+1					; same for working value for pixel 1
			leay	12,y							; skip the not used bytes from both margins
			dec	<linCnt						; decrement line counter
			lbne	nxtLin						; if not yet done, loop to do next line
****************************************************************************************************
* FRAME END CODE
****************************************************************************************************
			opt 	cc								; Frame control
;			sync									; avoid flickering
			ldb	<angStep						; get angle step
			bitb	#4								; has bit1 set?
			beq	odd							; no so it is 1st time, 3rd ... odd numbered time
			opt	cc
even		lda	#$1b							; next will write on buffer
			sta	$ffc9							;
			sta	$ffcc							; now show std screen, Page 1
			bra	setPage						; skip next section
			opt	cc								; NOT TO BE ACCOUNTED
odd		lda	#$0f							; next will write on std screen
			sta	$ffc8							;
			sta	$ffcd							; now show buffer, Page 3
			opt	cc
setPage	sta	nxtFrame+2					; update high byte of area to be updated
			addb	#4								; calculate next step (skipping a data word)
			stb	<angStep						; update it
			jmp	>nxtFrame					; next frame
****************************************************************************************************
* tables for Pixels 1/5, 2/6, 3/7, 4/8 (color value to be ORed on destination byte)
* These tables return the corresponding "color" value for the texture pixel moved to destination pixel
****************************************************************************************************
			align	$100
			fcb	$80,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 128 - 143
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 144 - 159
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 160 - 175
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 176 - 191
			fcb	$c0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 192 - 207
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 208 - 223
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 224 - 239
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 240 - 255
pixShft1	fcb	$00,$40,$80,$c0,$40,$00,$00,$00,$80,$00,$00,$00,$c0,$00,$00,$00	; 000 - 015
			fcb	$40,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 016 - 031
			fcb	$80,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 032 - 047
			fcb	$c0,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 048 - 063
			fcb	$40,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 064 - 079
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 080 - 095
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 096 - 111
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 112 - 127
* --------------------------------------------------------------------------------------------------
			fcb	$20,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 128 - 143
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 144 - 159
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 160 - 175
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 176 - 191
			fcb	$30,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 192 - 207
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 208 - 223
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 224 - 239
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 240 - 255
pixShft2	fcb	$00,$10,$20,$30,$10,$00,$00,$00,$20,$00,$00,$00,$30,$00,$00,$00	; 000 - 015
			fcb	$10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 016 - 031
			fcb	$20,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 032 - 047
			fcb	$30,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 048 - 063
			fcb	$10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 064 - 079
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 080 - 095
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 096 - 111
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 112 - 127
* --------------------------------------------------------------------------------------------------
			fcb	$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 128 - 143
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 144 - 159
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 160 - 175
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 176 - 191
			fcb	$0c,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 192 - 207
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 208 - 223
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 224 - 239
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 240 - 255
pixShft3	fcb	$00,$04,$08,$0c,$04,$00,$00,$00,$08,$00,$00,$00,$0c,$00,$00,$00	; 000 - 015
			fcb	$04,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 016 - 031
			fcb	$08,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 032 - 047
			fcb	$0c,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 048 - 063
			fcb	$04,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 064 - 079
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 080 - 095
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 096 - 111
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 112 - 127
* --------------------------------------------------------------------------------------------------
			fcb	$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 128 - 143
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 144 - 159
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 160 - 175
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 176 - 191
			fcb	$03,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 192 - 207
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 208 - 223
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 224 - 239
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 240 - 255
pixShft4	fcb	$00,$01,$02,$03,$01,$00,$00,$00,$02,$00,$00,$00,$03,$00,$00,$00	; 000 - 015
			fcb	$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 016 - 031
			fcb	$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 032 - 047
			fcb	$03,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 048 - 063
			fcb	$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 064 - 079
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 080 - 095
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 096 - 111
			fcb	$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 	; 112 - 127
****************************************************************************************************
* Tables for sine and cosine functions
* sintab: round(256*sin(a),0) - Angle 0-254 step 2. Each step is 360/128 = 2.8125
* costab: round(256*cos(a),0) - Angle 0-254 step 2
****************************************************************************************************
			fdb	$0000,$FFF3,$FFE7,$FFDA,$FFCE,$FFC2,$FFB6,$FFAA
			fdb	$FF9E,$FF93,$FF87,$FF7C,$FF72,$FF68,$FF5E,$FF54
			fdb	$FF4B,$FF42,$FF3A,$FF32,$FF2B,$FF24,$FF1E,$FF19
			fdb	$FF13,$FF0F,$FF0B,$FF08,$FF05,$FF03,$FF01,$FF00
			fdb	$FF00,$FF00,$FF01,$FF03,$FF05,$FF08,$FF0B,$FF0F
			fdb	$FF13,$FF19,$FF1E,$FF24,$FF2B,$FF32,$FF3A,$FF42
			fdb	$FF4B,$FF54,$FF5E,$FF68,$FF72,$FF7C,$FF87,$FF93
			fdb	$FF9E,$FFAA,$FFB6,$FFC2,$FFCE,$FFDA,$FFE7,$FFF3
sintab	fdb	$0000,$000D,$0019,$0026,$0032,$003E,$004A,$0056
			fdb	$0062,$006D,$0079,$0084,$008E,$0098,$00A2,$00AC
			fdb	$00B5,$00BE,$00C6,$00CE,$00D5,$00DC,$00E2,$00E7
			fdb	$00ED,$00F1,$00F5,$00F8,$00FB,$00FD,$00FF,$0100
			fdb	$0100,$0100,$00FF,$00FD,$00FB,$00F8,$00F5,$00F1
			fdb	$00ED,$00E7,$00E2,$00DC,$00D5,$00CE,$00C6,$00BE
			fdb	$00B5,$00AC,$00A2,$0098,$008E,$0084,$0079,$006D
			fdb	$0062,$0056,$004A,$003E,$0032,$0026,$0019,$000D
* --------------------------------------------------------------------------------------------------
			fdb	$FF00,$FF00,$FF01,$FF03,$FF05,$FF08,$FF0B,$FF0F
			fdb	$FF13,$FF19,$FF1E,$FF24,$FF2B,$FF32,$FF3A,$FF42
			fdb	$FF4B,$FF54,$FF5E,$FF68,$FF72,$FF7C,$FF87,$FF93
			fdb	$FF9E,$FFAA,$FFB6,$FFC2,$FFCE,$FFDA,$FFE7,$FFF3
			fdb	$0000,$000D,$0019,$0026,$0032,$003E,$004A,$0056
			fdb	$0062,$006D,$0079,$0084,$008E,$0098,$00A2,$00AC
			fdb	$00B5,$00BE,$00C6,$00CE,$00D5,$00DC,$00E2,$00E7
			fdb	$00ED,$00F1,$00F5,$00F8,$00FB,$00FD,$00FF,$0100
costab	fdb	$0100,$0100,$00FF,$00FD,$00FB,$00F8,$00F5,$00F1
			fdb	$00ED,$00E7,$00E2,$00DC,$00D5,$00CE,$00C6,$00BE
			fdb	$00B5,$00AC,$00A2,$0098,$008E,$0084,$0079,$006D
			fdb	$0062,$0056,$004A,$003E,$0032,$0026,$0019,$000D
			fdb	$0000,$FFF3,$FFE7,$FFDA,$FFCE,$FFC2,$FFB6,$FFAA
			fdb	$FF9E,$FF93,$FF87,$FF7C,$FF72,$FF68,$FF5E,$FF54
			fdb	$FF4B,$FF42,$FF3A,$FF32,$FF2B,$FF24,$FF1E,$FF19
			fdb	$FF13,$FF0F,$FF0B,$FF08,$FF05,$FF03,$FF01,$FF00
****************************************************************************************************
* Tables for the coordinates (X,Y) of the first Line leftmost pixel of the texture. 
* both are 16 bits with high byte as byte number and low byte for adding sine-cosine at each step
* --------------------------------------------------------------------------------------------------
* origin (0,0) from viewport is at X=24, Y=56 with respect to the actual screen origin
* so we apply these values for axes translation
* The -32 applied to PosY avoids positive values greater than 127 (could behave as negative)
* Radius = (80/2)/cos(45) in pixels
* posIX = round(256*((Radius*(cos(45)-cos(45-Angle))+24)),0)
* posIY = round(256*((Radius*(sin(45)-sin(45-Angle))+56-32)),0)																			
****************************************************************************************************
			fdb	$6800,$69EA,$6BBA,$6D70,$6F09,$7085,$71E4,$7323
			fdb	$7443,$7543,$7622,$76E0,$777B,$77F5,$784C,$7880
			fdb	$7892,$7880,$784C,$77F5,$777B,$76E0,$7622,$7543
			fdb	$7443,$7323,$71E4,$7085,$6F09,$6D70,$6BBA,$69EA
			fdb	$6800,$65FD,$63E3,$61B3,$5F6E,$5D15,$5AAB,$5830
			fdb	$55A6,$530F,$506C,$4DBF,$4B09,$484D,$458B,$42C7
			fdb	$4000,$3D39,$3A75,$37B3,$34F7,$3241,$2F94,$2CF1
			fdb	$2A5A,$27D0,$2555,$22EB,$2092,$1E4D,$1C1D,$1A03
posIX		fdb	$1800,$1616,$1446,$1290,$10F7,$0F7B,$0E1C,$0CDD
			fdb	$0BBD,$0ABD,$09DE,$0920,$0885,$080B,$07B4,$0780
			fdb	$076E,$0780,$07B4,$080B,$0885,$0920,$09DE,$0ABD
			fdb	$0BBD,$0CDD,$0E1C,$0F7B,$10F7,$1290,$1446,$1616
			fdb	$1800,$1A03,$1C1D,$1E4D,$2092,$22EB,$2555,$27D0
			fdb	$2A5A,$2CF1,$2F94,$3241,$34F7,$37B3,$3A75,$3D39
			fdb	$4000,$42C7,$458B,$484D,$4B09,$4DBF,$506C,$530F
			fdb	$55A6,$5830,$5AAB,$5D15,$5F6E,$61B3,$63E3,$65FD
* --------------------------------------------------------------------------------------------------
			fdb	$6800,$65FD,$63E3,$61B3,$5F6E,$5D15,$5AAB,$5830
			fdb	$55A6,$530F,$506C,$4DBF,$4B09,$484D,$458B,$42C7
			fdb	$4000,$3D39,$3A75,$37B3,$34F7,$3241,$2F94,$2CF1
			fdb	$2A5A,$27D0,$2555,$22EB,$2092,$1E4D,$1C1D,$1A03
			fdb	$1800,$1616,$1446,$1290,$10F7,$0F7B,$0E1C,$0CDD
			fdb	$0BBD,$0ABD,$09DE,$0920,$0885,$080B,$07B4,$0780
			fdb	$076E,$0780,$07B4,$080B,$0885,$0920,$09DE,$0ABD
			fdb	$0BBD,$0CDD,$0E1C,$0F7B,$10F7,$1290,$1446,$1616
posIY		fdb	$1800,$1A03,$1C1D,$1E4D,$2092,$22EB,$2555,$27D0
			fdb	$2A5A,$2CF1,$2F94,$3241,$34F7,$37B3,$3A75,$3D39
			fdb	$4000,$42C7,$458B,$484D,$4B09,$4DBF,$506C,$530F
			fdb	$55A6,$5830,$5AAB,$5D15,$5F6E,$61B3,$63E3,$65FD
			fdb	$6800,$69EA,$6BBA,$6D70,$6F09,$7085,$71E4,$7323
			fdb	$7443,$7543,$7622,$76E0,$777B,$77F5,$784C,$7880
			fdb	$7892,$7880,$784C,$77F5,$777B,$76E0,$7622,$7543
			fdb	$7443,$7323,$71E4,$7085,$6F09,$6D70,$6BBA,$69EA
****************************************************************************************************
			end 	start
		